@@ -8,10 +8,6 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "./champlain-memphis-renderer.h" */
-GType champlain_memphis_rule_type_get_type (void) G_GNUC_CONST;
-#define CHAMPLAIN_TYPE_MEMPHIS_RULE_TYPE champlain_memphis_rule_type_get_type()
-
 /* enumerations from "./champlain-marker-layer.h" */
 GType champlain_selection_mode_get_type (void) G_GNUC_CONST;
 #define CHAMPLAIN_TYPE_SELECTION_MODE champlain_selection_mode_get_type()
